pub enum BitfieldOrder {
LowestFirst,
HighestFirst,
}Expand description
How a bit-field is allocated within its storage unit.
Variants
LowestFirst
The first field declared gets the low order bits, which is every little-endian target here.
HighestFirst
The first field declared gets the high order bits, which is s390x and every other big-endian ELF target.